# Nebari Plugin - Airflow

[![PyPI - Version](https://img.shields.io/pypi/v/nebari-plugin-airflow.svg)](https://pypi.org/project/nebari-plugin-airflow)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/nebari-plugin-airflow.svg)](https://pypi.org/project/nebari-plugin-airflow)
